from askdata.askdata_client import *
from NotebookScripter import receive_parameter
from askdata.human2query import ask_dataframe
from askdata import askdata_pandas_extension